ActionSheetOption class

操作表选项模型

Constructors

ActionSheetOption({required String title, dynamic value, bool isDestructive = false, bool isDefault = false})
构造函数
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isDefault bool
是否为默认选中项
final
isDestructive bool
是否为破坏性操作(红色文字)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
选项标题
final
value → dynamic
选项值
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited