PPBottomSheet class

底部弹出框

PPBottomSheet.show(
  height: 0.3,
  backgroundColor: HexColor('#F0FED8'),
  borderRadius: BorderRadius.circular(16.w),
  child: Text(
    '这是一个底部弹出框',
    style: TextStyle(
      fontSize: 16.sp,
      fontWeight: FontWeight.w700,
      fontFamily: FontName.nunito,
      color: Colors.black,
    ),
  ),
);

Constructors

PPBottomSheet()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

show({double height = 300, Widget? child, Color barrierColor = Colors.transparent, Color backgroundColor = Colors.white, BorderRadius? borderRadius, bool isScrollControlled = true, bool isDismissible = true, bool enableDrag = true, Clip? clipBehavior}) → void
显示底部弹出框