PPCenterDialog class

居中弹窗

居中弹窗是一种弹窗类型,它会在屏幕中央显示一个弹窗,而不是顶部或底部。 居中弹窗通常用于显示重要的提示信息或要求用户确认的操作。

PPCenterDialog.show(
  barrierColor: Colors.transparent,
  backgroundColor: Colors.white,
  child:SubsPersuageAlert(),
);

Constructors

PPCenterDialog()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

show({Color? barrierColor, bool barrierDismissible = false, Color backgroundColor = Colors.transparent, Offset offset = const Offset(0, 0), Widget? child}) → void
显示居中弹窗