THMessages class

Constructors

THMessages()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dayAgo(int hours) String
Message for when the elapsed time is about a day.
daysAgo(int days) String
Message for when the elapsed time is in days.
hourAgo(int minutes) String
Message for when the elapsed time is about an hour.
hoursAgo(int hours) String
Message for when the elapsed time is in hours.
justNow(int seconds) String
Message when the elapsed time is less than 15 seconds.
minAgo(int minutes) String
Message for when the elapsed time is about a minute.
minsAgo(int minutes) String
Message for when the elapsed time is in minutes.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prefixAgo() String
Prefix added before the time message.
secsAgo(int seconds) String
Message for when the elapsed time is less than a minute.
suffixAgo() String
Suffix added after the time message.
toString() String
A string representation of this object.
inherited
wordSeparator() String
Word separator to be used when joining the parts of the message.

Operators

operator ==(Object other) bool
The equality operator.
inherited