CountryUtil class

国家工具类

用于判断当前用户所在的国家是否为指定的国家

启动的时候获取设备的地区信息,然后设置CountryUtil.countryCode

Constructors

CountryUtil()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

countryCode String
getter/setter pair

Static Methods

isArabic() bool
判断当前是否为阿拉伯语用户
isChina() bool
判断当前是否为中国用户
isEnglish() bool
判断当前是否为英语用户
isFilipino() bool
判断当前是否为菲律宾语用户
isFrench() bool
判断当前是否为法语用户
isGermany() bool
判断当前是否为德语用户
isHindi() bool
判断当前是否为印地语用户
isIndonesian() bool
判断当前是否为印尼语用户
isItalian() bool
判断当前是否为意大利语用户
isJapanese() bool
判断当前是否为日语用户
isKorea() bool
判断当前是否为韩语用户
isPolish() bool
判断当前是否为波兰语用户
isPortuguese() bool
判断当前是否为葡萄牙语用户
isRussian() bool
判断当前是否为俄语用户
isSpanish() bool
判断当前是否为西班牙语用户
isThai() bool
判断当前是否为泰语用户
isTurkish() bool
判断当前是否为土耳其语用户
isVietnamese() bool
判断当前是否为越南语用户