onInit method

  1. @override
void onInit()
override

Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.

Implementation

@override
void onInit() {
  super.onInit();
  _connectivity = Connectivity();
  _connectivitySubscription = _connectivity.onConnectivityChanged.listen(
    _updateNetworkStatus,
  );
  checkConnectivity();
  Logger.log('网络初始化完成,开启监听中...');
}