PPActionSheet class
底部操作表
PPActionSheet.show(
title: 'Dingyue_FamilyShare'.localized,
message: 'Dingyue_FamilyShare_Desc'.localized,
options: [
ActionSheetOption(title: 'A'),
ActionSheetOption(title: 'B'),
ActionSheetOption(title: 'C'),
],
onOptionSelected: (index, option) {
print('onOptionSelected: $index ${option.title}');
},
);
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
show(
{String? title, String? message, required List< ActionSheetOption> options, String cancelText = '取消', void onOptionSelected(int index, ActionSheetOption option)?, void onCancel()?}) → void - 显示操作表