NetworkUtil class
网络连接状态控制器。
提供当前网络类型、连接状态和可选的网络健康检查;不包含公网 IP 或 地理位置查询功能。
- Inheritance
-
- Object
- GetLifeCycle
- DisposableInterface
- GetxController
- NetworkUtil
- Implemented types
Constructors
Properties
- checkMinutesInterval ↔ int
-
定时健康检查的间隔(分钟)。
getter/setter pair
- enableHealthCheck ↔ bool
-
是否启用网络健康检查。
getter/setter pair
-
extraUrls
→ List<
String> -
参与网络健康检查的额外地址。
final
- fastResponseTime ↔ int
-
最近一次健康检查中最快节点的响应时间(毫秒)。
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
no setterinherited
- healthCheckDebounceSeconds ↔ int
-
连接变化后执行健康检查前的防抖时间(秒)。
getter/setter pair
- initialized → bool
-
Checks whether the controller has already been initialized.
no setterinherited
- isClosed → bool
-
Checks whether the controller has already been closed.
no setterinherited
- isConnected → RxBool
-
当前是否存在网络连接。
final
- listeners → int
-
no setterinherited
-
netType
→ Rx<
NetworkType> -
当前网络类型。
final
-
onDelete
→ InternalFinalCallback<
void> -
Internal callback that starts the cycle of this controller.
finalinherited
-
onStart
→ InternalFinalCallback<
void> -
Called at the exact moment the widget is allocated in memory.
It uses an internal "callable" type, to avoid any @overrides in subclases.
This method should be internal and is required to define the
lifetime cycle of the subclass.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
status
→ Rx<
NetworkStatus> -
当前网络健康状态。
final
Methods
-
$configureLifeCycle(
) → void -
inherited
-
addListener(
GetStateUpdate listener) → Disposer -
Register a closure to be called when the object notifies its listeners.
inherited
-
addListenerId(
Object? key, GetStateUpdate listener) → Disposer -
inherited
-
checkConnectivity(
) → Future< void> - 获取并更新当前网络连接状态。
-
checkNetworkHealth(
{int slowThresholdMs = 3000, int timeoutMs = 10000}) → Future< NetworkStatus> - 检查网络是否可访问,并以最快成功请求的响应时间判定健康状态。
-
dispose(
) → void -
inherited
-
disposeId(
Object id) → void -
To dispose an
idfrom future updates(), this ids are registered byGetBuilder()or similar, so is a way to unlink the state change with the Widget from the Controller.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyChildrens(
) → void -
inherited
-
onClose(
) → void -
Called before onDelete method. onClose might be used to
dispose resources used by the controller. Like closing events,
or streams before the controller is destroyed.
Or dispose objects that can potentially create some memory leaks,
like TextEditingControllers, AnimationControllers.
Might be useful as well to persist some data on disk.
override
-
onInit(
) → void -
Called immediately after the widget is allocated in memory.
You might use this to initialize something for the controller.
override
-
onReady(
) → void -
Called 1 frame after onInit(). It is the perfect place to enter
navigation events, like snackbar, dialogs, or a new route, or
async request.
inherited
-
refresh(
) → void -
inherited
-
refreshGroup(
Object id) → void -
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies.
inherited
-
removeListenerId(
Object id, VoidCallback listener) → void -
inherited
-
setHealthCheckDebounceSeconds(
int seconds) → void - 设置连接变化后健康检查的防抖时间(秒)。
-
setHealthCheckEnabled(
bool enabled) → void - 设置网络健康检查开关。
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
[List< Object> ? ids, bool condition = true]) → void -
Rebuilds
GetBuildereach time you callupdate(); Can take a List ofids, that will only update the matchingGetBuilder( id: ),idscan be reused amongGetBuilderslike group tags. The update will only notify the Widgets, ifconditionis true.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited